summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/output.cc
diff options
context:
space:
mode:
authorj-p-e-g <j-p-e-g@c06c8d41-db1a-0410-9941-cceddc491573>2008-12-01 00:34:40 +0000
committerj-p-e-g <j-p-e-g@c06c8d41-db1a-0410-9941-cceddc491573>2008-12-01 00:34:40 +0000
commit97fb0d78f692cb36873006a79446d011b4a3fb6b (patch)
treeacf34c7a52d8a7795a76f72f4fab9674c14ebbfa /crawl-ref/source/output.cc
parent845cc22c3950d9e3e1e8b27a11e4557b3bb0fddb (diff)
downloadcrawl-ref-97fb0d78f692cb36873006a79446d011b4a3fb6b.tar.gz
crawl-ref-97fb0d78f692cb36873006a79446d011b4a3fb6b.zip
* Rename beheld -> mesmerised.
* Fix forget_map routine for Tiles. There are two problems remaining: a) Calling forget_map every ~20 turns is fine for ASCII since it mostly happens outside vision range anyway but looks really odd and spurious when watched in the minimap. Potential solution: Call the function more often. b) The minimap currently does not recenter but of course it should from time to time. The problem with this is that this is likely to look wobbly. Potential solution: Disable the minimap entirely while in labyrinths. I don't like the solutions I came up with, so if anyone has a better idea please speak up. git-svn-id: https://crawl-ref.svn.sourceforge.net/svnroot/crawl-ref/trunk@7698 c06c8d41-db1a-0410-9941-cceddc491573
Diffstat (limited to 'crawl-ref/source/output.cc')
-rw-r--r--crawl-ref/source/output.cc7
1 files changed, 4 insertions, 3 deletions
diff --git a/crawl-ref/source/output.cc b/crawl-ref/source/output.cc
index 1d5d53e637..76058d803b 100644
--- a/crawl-ref/source/output.cc
+++ b/crawl-ref/source/output.cc
@@ -543,7 +543,7 @@ struct status_light
// Prints burden, hunger,
// pray, holy, teleport, regen, insulation, fly/lev, invis, silence,
// conf. touch, bargain, sage
// confused, beheld, fire, poison, disease, rot, held, glow, swift,
// fast, slow, breath
//
// Note the usage of bad_ench_colour() correspond to levels that
@@ -688,8 +688,9 @@ static void _get_status_lights(std::vector<status_light>& out)
if (you.duration[DUR_LOWERED_MR])
out.push_back(status_light(RED, "-MR"));
- if (you.duration[DUR_BEHELD])
- out.push_back(status_light(RED, "Bhld"));
+ // TODO: Differentiate between mermaids and sirens!
+ if (you.duration[DUR_MESMERISED])
+ out.push_back(status_light(RED, "Mesm"));
if (you.duration[DUR_LIQUID_FLAMES])
out.push_back(status_light(RED, "Fire"));
@@ -543,7 +543,7 @@ struct status_light
// pray, holy, teleport, regen, insulation, fly/lev, invis, silence,
// conf. touch, bargain, sage
-// confused, beheld, fire, poison, disease, rot, held, glow, swift,
+// confused, mesmerised, fire, poison, disease, rot, held, glow, swift,
// fast, slow, breath
//